Short Answer
------------

.. shortanswer:: shorta1

   You can ask your students to answer reflective questions or short essays in the box provided.


.. reveal:: shorta1_src
   :showtitle: Show Source
   :hidetitle: Hide Source
   :modaltitle: Source for the example above

   .. code-block:: rst

      .. shortanswer:: shorta1

         You can ask your students to answer reflective questions or short essays in the box provided.
